@@ -1,6 +1,6 @@
 package Mite;
 
-use version; our $VERSION = qv("v0.0.1");
+use version; our $VERSION = qv("v0.0.2");
 
 =head1 NAME
 
@@ -111,7 +111,7 @@ else, please read L<Moose> and L<Moose::Manual>.
 
 =head2 C<has>
 
-Supports C<is> and C<default>.
+Supports C<is>, C<init_arg>, C<required>, and C<default>.
 
 =head2 C<extends>
 
