@@ -1,49 +1,53 @@
 package Mite::Project;
-
-use feature ':5.10';
-use Mouse;
+use Mite::MyMoo;
 with qw(
     Mite::Role::HasConfig
     Mite::Role::HasDefault
 );
 
-use Method::Signatures;
-use Path::Tiny;
-use Carp;
-
 use Mite::Source;
 use Mite::Class;
 
 has sources =>
-  is            => 'ro',
-  isa           => 'HashRef[Mite::Source]',
+  is            => ro,
+  isa           => HashRef[InstanceOf['Mite::Source']],
   default       => sub { {} };
 
-method classes() {
+sub classes {
+    my $self = shift;
+
     my %classes = map { %{$_->classes} }
                   values %{$self->sources};
     return \%classes;
 }
 
 # Careful not to create a class.
-method class($name) {
+sub class {
+    my ( $self, $name ) = ( shift, @_ );
+
     return $self->classes->{$name};
 }
 
 # Careful not to create a source.
-method source($file) {
+sub source {
+    my ( $self, $file ) = ( shift, @_ );
+
     return $self->sources->{$file};
 }
 
-method add_sources(@sources) {
+sub add_sources {
+    my ( $self, @sources ) = ( shift, @_ );
+
     for my $source (@sources) {
         $self->sources->{$source->file} = $source;
     }
 }
 
-method source_for($file) {
+sub source_for {
+    my ( $self, $file ) = ( shift, @_ );
+
     # Normalize the path.
-    $file = path($file)->realpath;
+    $file = Path::Tiny::path($file)->realpath;
 
     return $self->sources->{$file} ||= Mite::Source->new(
         file    => $file,
@@ -53,12 +57,21 @@ method source_for($file) {
 
 
 # This is the shim Mite.pm uses when compiling.
-method inject_mite_functions(:$package, :$file) {
+sub inject_mite_functions {
+    state $sig = sig_named(
+        { head => [ Object ], named_to_list => true },
+        package => Any,
+        file => Any,
+    );
+    my ( $self, $package, $file ) = &$sig;
+
     my $source = $self->source_for($file);
     my $class  = $source->class_for($package);
 
     no strict 'refs';
-    *{ $package .'::has' } = func( $name, %args ) {
+    *{ $package .'::has' } = sub {
+        my ( $name, %args ) = @_;
+
         if( my $is_extension = $name =~ s{^\+}{} ) {
             $class->extend_attribute(
                 name    => $name,
@@ -77,7 +90,9 @@ method inject_mite_functions(:$package, :$file) {
         return;
     };
 
-    *{ $package .'::extends' } = func(@classes) {
+    *{ $package .'::extends' } = sub {
+        my (@classes) = @_;
+
         $class->extends(\@classes);
 
         return;
@@ -86,7 +101,9 @@ method inject_mite_functions(:$package, :$file) {
     return;
 }
 
-method write_mites() {
+sub write_mites {
+    my $self = shift;
+
     for my $source (values %{$self->sources}) {
         $source->compiled->write;
     }
@@ -94,64 +111,86 @@ method write_mites() {
     return;
 }
 
-method load_files(ArrayRef $files, $inc_dir?) {
+sub load_files {
+    state $sig = sig_pos( 1, ArrayRef, 0 );
+    my ( $self, $files, $inc_dir ) = &$sig;
+
     local $ENV{MITE_COMPILE} = 1;
     local @INC = @INC;
     unshift @INC, $inc_dir if defined $inc_dir;
     for my $file (@$files) {
-        my $pm_file = path($file)->relative($inc_dir);
+        my $pm_file = Path::Tiny::path($file)->relative($inc_dir);
         require $pm_file;
     }
 
     return;
 }
 
-method find_pms($dir=$self->config->data->{source_from}) {
+sub find_pms {
+    my ( $self, $dir ) = ( shift, @_ );
+    $dir //= $self->config->data->{source_from};
+
     return $self->_recurse_directory(
         $dir,
-        func($path) {
-            return if -d $path;
-            return unless $path =~ m{\.pm$};
-            return if $path =~ m{\.mite\.pm$};
-            return 1;
+        sub {
+            my $path = shift;
+            return false if -d $path;
+            return false unless $path =~ m{\.pm$};
+            return false if $path =~ m{\.mite\.pm$};
+            return true;
         }
     );
 }
 
-method load_directory($dir=$self->config->data->{source_from}) {
+sub load_directory {
+    my ( $self, $dir ) = ( shift, @_ );
+    $dir //= $self->config->data->{source_from};
+
     $self->load_files( [$self->find_pms($dir)], $dir );
 
     return;
 }
 
-method find_mites($dir=$self->config->data->{compiled_to}) {
+sub find_mites {
+    my ( $self, $dir ) = ( shift, @_ );
+    $dir //= $self->config->data->{compiled_to};
+
     return $self->_recurse_directory(
         $dir,
-        func($path) {
-            return if -d $path;
-            return 1 if $path =~ m{\.mite\.pm$};
-            return;
+        sub {
+            my $path = shift;
+            return false if -d $path;
+            return true if $path =~ m{\.mite\.pm$};
+            return false;
         }
     );
 }
 
-method clean_mites($dir=$self->config->data->{compiled_to}) {
+sub clean_mites {
+    my ( $self, $dir ) = ( shift, @_ );
+    $dir //= $self->config->data->{compiled_to};
+
     for my $file ($self->find_mites($dir)) {
-        path($file)->remove;
+        Path::Tiny::path($file)->remove;
     }
 
     return;
 }
 
-method clean_shim() {
+sub clean_shim {
+    my $self = shift;
+
     return $self->_project_shim_file->remove;
 }
 
 # Recursively gather all the pm files in a directory
-method _recurse_directory(Str $dir, CodeRef $check) {
+sub _recurse_directory {
+    state $sig = sig_pos( Object, Path, CodeRef );
+    my ( $self, $dir, $check ) = &$sig;
+
     my @pm_files;
 
-    my $iter = path($dir)->iterator({ recurse => 1, follow_symlinks => 1 });
+    my $iter = $dir->iterator({ recurse => 1, follow_symlinks => 1 });
     while( my $path = $iter->() ) {
         next unless $check->($path);
         push @pm_files, $path;
@@ -160,7 +199,9 @@ method _recurse_directory(Str $dir, CodeRef $check) {
     return @pm_files;
 }
 
-method init_project($project_name) {
+sub init_project {
+    my ( $self, $project_name ) = ( shift, @_ );
+
     $self->config->make_mite_dir;
 
     $self->write_default_config(
@@ -170,7 +211,9 @@ method init_project($project_name) {
     return;
 }
 
-method add_mite_shim() {
+sub add_mite_shim {
+    my $self = shift;
+
     my $shim_file = $self->_project_shim_file;
     $shim_file->parent->mkpath;
 
@@ -189,7 +232,9 @@ OUT
     return $shim_file;
 }
 
-method _project_shim_file() {
+sub _project_shim_file {
+    my $self = shift;
+
     my $config = $self->config;
     my $shim_package = $config->data->{shim};
     my $shim_dir     = $config->data->{source_from};
@@ -197,15 +242,17 @@ method _project_shim_file() {
     my $shim_file = $shim_package;
     $shim_file =~ s{::}{/}g;
     $shim_file .= ".pm";
-    return path($shim_dir, $shim_file);
+    return Path::Tiny::path($shim_dir, $shim_file);
 }
 
-method _find_mite_shim() {
+sub _find_mite_shim {
+    my $self = shift;
+
     for my $dir (@INC) {
         # Avoid code refs in @INC
         next if ref $dir;
 
-        my $shim = path($dir, "Mite", "Shim.pm");
+        my $shim = Path::Tiny::path($dir, "Mite", "Shim.pm");
         return $shim if -e $shim;
     }
 
@@ -215,8 +262,12 @@ Can't locate Mite::Shim in \@INC.  \@INC contains:
 ERROR
 }
 
-method write_default_config(Str $project_name, %args) {
-    my $libdir = path('lib');
+sub write_default_config {
+    my $self = shift;
+    my $project_name = Str->(shift);
+    my %args = @_;
+
+    my $libdir = Path::Tiny::path('lib');
     $self->config->write_config({
         project         => $project_name,
         shim            => $project_name.'::Mite',
